==> kvpnc-trinity_14.0.4.orig.tar.xz: kvpnc-trinity-14.0.4/src/displaycertdialog.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DISPLAYCERTDIALOG_H
#define DISPLAYCERTDIALOG_H

#include <kdialogbase.h>
#include "kvpncconfig.h"
#include "displaycertdialogbase.h"

#include <tqstringlist.h>


/**
	@author Christoph Thielecke <crissi99@gmx.de>
*/
class DisplayCertDialog : public KDialogBase
{
	public:
		DisplayCertDialog ( TQWidget *parent, const char* caption, KVpncConfig *GlobalConfig );

		~DisplayCertDialog();

	public:
		DisplayCertDialogBase *main;

	public:
		KVpncConfig *GlobalConfig;
		void parseCertData();
		TQStringList CertDataList;

};

#endif

==> kvpnc-trinity_14.1.6~pre2.orig.tar.xz: kvpnc-trinity-14.1.6~pre2+b555b77b/src/displaycertdialog.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DISPLAYCERTDIALOG_H
#define DISPLAYCERTDIALOG_H

#include <kdialogbase.h>
#include "kvpncconfig.h"
#include "displaycertdialogbase.h"

#include <tqstringlist.h>


/**
	@author Christoph Thielecke <crissi99@gmx.de>
*/
class DisplayCertDialog : public KDialogBase
{
	public:
		DisplayCertDialog ( TQWidget *parent, const TQString& caption, KVpncConfig *GlobalConfig );

		~DisplayCertDialog();

	public:
		DisplayCertDialogBase *main;

	public:
		KVpncConfig *GlobalConfig;
		void parseCertData();
		TQStringList CertDataList;

};

#endif
